@@ -5,6 +5,9 @@ print(persistent)
 
 # Make sure the extension modules can be imported.
 
+import persistent._ring
+print(persistent._ring)
+
 import persistent._timestamp
 print(persistent._timestamp)
 
